@@ -50,7 +50,6 @@ signeture
 print <<'END';
 Calling extended methods:
 	inher  - no extended, only inherited
-	simple - no extended, only modified
 
 	before - extended with :before modifier
 	around - extended with :around modifier
@@ -75,7 +74,7 @@ cmpthese -1 => {
 	super => sub{
 		X->i(42) == 42 or die;
 	},
-	simple => sub{
-		X->j(42) == 42 or die;
-	},
+#	simple => sub{
+#		X->j(42) == 42 or die;
+#	},
 };
